==> haskell-conduit-1.2.10-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: conduit
version: 1.2.10
id: conduit-1.2.10-JpwcbBZZrSj1n2q4Mh3BJS
key: conduit-1.2.10-JpwcbBZZrSj1n2q4Mh3BJS
license: MIT
maintainer: michael@snoyman.com
homepage: http://github.com/snoyberg/conduit
synopsis: Streaming data processing library.
description:
    `conduit` is a solution to the streaming data problem, allowing for production,
    transformation, and consumption of streams of data in constant memory. It is an
    alternative to lazy I\/O which guarantees deterministic resource handling.
    .
    For more information about conduit in general, and how this package in
    particular fits into the ecosystem, see [the conduit
    homepage](https://github.com/snoyberg/conduit#readme).
    .
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/conduit>.
category: Data, Conduit
author: Michael Snoyman
exposed: True
exposed-modules:
    Data.Conduit Data.Conduit.List Data.Conduit.Internal
    Data.Conduit.Lift Data.Conduit.Internal.Fusion
    Data.Conduit.Internal.List.Stream
hidden-modules: Data.Conduit.Internal.Pipe
                Data.Conduit.Internal.Conduit
abi: 7c7b7f5cee5d794e3887a96e2ebfbda1
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/conduit-1.2.10
library-dirs: /usr/lib/ghc-8.0.1/site-local/conduit-1.2.10
data-dir: /usr/share/i386-linux-ghc-8.0.1/conduit-1.2.10
hs-libraries: HSconduit-1.2.10-JpwcbBZZrSj1n2q4Mh3BJS
depends:
    base-4.9.0.0 exceptions-0.8.3-5cAKIsqc1DD7jaNW3zLxAN
    lifted-base-0.2.3.10-GN8bGJb6NKpLjv5n9gQH0C
    mmorph-1.0.9-DmSwQqk5nLj7roLAcydGz
    monad-control-1.0.1.0-CVvkY5Vr2NNGCNJRXug3iR
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    primitive-0.6.2.0-3HSsNCfUEEE4fjqDYVydYZ
    resourcet-1.1.9-CymaqmR8zCeCrSnerfb4Fa transformers-0.5.2.0
    transformers-base-0.4.4-LWS58Nywv1PJoy1IFDbvS4
haddock-interfaces: /usr/share/doc/haskell-conduit/html/conduit.haddock
haddock-html: /usr/share/doc/haskell-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-conduit-1.2.10-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: conduit
version: 1.2.10
id: conduit-1.2.10-Jh04T8HFIqp3EspViruWGc
key: conduit-1.2.10-Jh04T8HFIqp3EspViruWGc
license: MIT
maintainer: michael@snoyman.com
homepage: http://github.com/snoyberg/conduit
synopsis: Streaming data processing library.
description:
    `conduit` is a solution to the streaming data problem, allowing for production,
    transformation, and consumption of streams of data in constant memory. It is an
    alternative to lazy I\/O which guarantees deterministic resource handling.
    .
    For more information about conduit in general, and how this package in
    particular fits into the ecosystem, see [the conduit
    homepage](https://github.com/snoyberg/conduit#readme).
    .
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/conduit>.
category: Data, Conduit
author: Michael Snoyman
exposed: True
exposed-modules:
    Data.Conduit Data.Conduit.List Data.Conduit.Internal
    Data.Conduit.Lift Data.Conduit.Internal.Fusion
    Data.Conduit.Internal.List.Stream
hidden-modules: Data.Conduit.Internal.Pipe
                Data.Conduit.Internal.Conduit
abi: bede33c4a607c98ab50edad08b25f45c
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/conduit-1.2.10
library-dirs: /usr/lib/ghc-8.0.1/site-local/conduit-1.2.10
data-dir: /usr/share/i386-linux-ghc-8.0.1/conduit-1.2.10
hs-libraries: HSconduit-1.2.10-Jh04T8HFIqp3EspViruWGc
depends:
    base-4.9.0.0 exceptions-0.8.3-5cAKIsqc1DD7jaNW3zLxAN
    lifted-base-0.2.3.11-6Z5sbMH60be9gIey8uuzks
    mmorph-1.0.9-DmSwQqk5nLj7roLAcydGz
    monad-control-1.0.1.0-CVvkY5Vr2NNGCNJRXug3iR
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    primitive-0.6.2.0-3HSsNCfUEEE4fjqDYVydYZ
    resourcet-1.1.9-LttKXnENmd16hW52fqUDxA transformers-0.5.2.0
    transformers-base-0.4.4-LWS58Nywv1PJoy1IFDbvS4
haddock-interfaces: /usr/share/doc/haskell-conduit/html/conduit.haddock
haddock-html: /usr/share/doc/haskell-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
